#import "tuneup/tuneup.js"

extend(UIATableView.prototype, {
  // taps field to make it first responder, then sets value
  setValueForField: function(value, field) {
    UIALogger.logMessage("Setting '" + value + "' for field '" + field + "'");
    var fieldCell = this.cellNamed(field);
    fieldCell.tap();
    fieldCell.textFields()[0].setValue(value);
  }
});

function msg(message) {
  UIALogger.logMessage(message);
}

function add(target, app) {
  UIALogger.logMessage("Tapping add button");
  app.mainWindow().navigationBar().buttons()["Add"].tap();
  target.delay(1);
  UIALogger.logMessage("Add button tapped");
}

function addFolderWithNameAndCancel(target, app, name, shouldHitCancel) {
  var w = app.mainWindow();
  var itemTable = w.tableViews()[0];
  
  msg("Storing number of items currently in table view");
  var countBefore = itemTable.cells.length;
  msg("countBefore = " + countBefore);
  add(target, app);
  msg("Selecting folder from action sheet");
  app.actionSheet().buttons()["Folder"].tap();
  app.actionSheet().waitForInvalid();
  
  msg("ActionSheet disappeared, checking if we moved to Edit Folder screen");
  assertEquals(app.navigationTitle(), "Edit Folder");
  msg("Moved to Edit Fodler screen");

  msg("Checking if all fields are there");  
  var table = w.tableViews()[0];
  table.assertCellNamed("name");
  table.assertCellNamed("folder");
  
  // set name
  msg("Setting name of folder to \"" + name + "\"");
  table.setValueForField(name, "name");
  
  if (shouldHitCancel) {
    msg("Cancelling");
    app.mainWindow().navigationBar().buttons()["Cancel"].tap();
  }
  else {
    msg("Tapping done");
    app.mainWindow().navigationBar().buttons()["Done"].tap();
  }
  table.waitForInvalid();
  
  itemTable = w.tableViews()[0];
  if (shouldHitCancel) {
    assertEquals(countBefore, itemTable.cells.length);
  }
  else {
    // ensure the newly created folder exists
    msg("Checking the new folder exists");
    itemTable.assertCellNamed(name);
    assertEquals(countBefore + 1, itemTable.cells.length);
  }

}

test("Add and Cancel", function(target, app) {
  add(target, app);
  app.actionSheet().buttons()["Cancel"].tap();
  app.actionSheet().waitForInvalid();
});

test("Add Folder and Cancel", function(target, app) {
  
  addFolderWithNameAndCancel(target, app, "not used", true);
});

test("Add Folder", function(target, app) {
  addFolderWithNameAndCancel(target, app, "a", false);
  // get new table
  var table = app.mainWindow().tableViews()[0];
  var c = table.cellNamed(FOLDER_NAME);
  c.dragInsideWithOptions({
						  startOffset:{x:0.3, y:0.5}, 
						  endOffset:{x:0.6, y:0.5},
						  touchCount: 1,
						  duration: 0.5
  });
});